Frequently Asked Questions (FAQs)
=================================

This is a nonexhaustive list of frequently asked questions.

**Q:** What can I do with Awpy?
    You can use Awpy to parse, analyze and visualize Counter-Strik 2 demo files (demos).

**Q:** How do I install Awpy?
    You can install Awpy in Python by running ``pip install awpy``.

**Q:** The parser returns weird rounds or data!
    Please note that Awpy parses, and cleans, data from the demo file assuming the demo is from a competitive Counter-Strike 2 match (e.g., from HLTV, FACEIT or competitive matchmaking).

**Q:** Where can I get documentation for the parsed data?
    Please look at :doc:`../modules/parser_output`.

**Q:** Is Awpy available in other languages?
    Awpy is only available in Python. However, you can use a :doc:`../modules/cli` to parse demos with Awpy via a command-line interface.

**Q:** I want to parse everything in the demo / I have specific parsing needs, can Awpy help?
    Probably not -- Awpy is focused on competitive play and analysis. Awpy is built on the very flexible `demoparser2 library <https://pypi.org/project/demoparser2/>`_. You may still find Awpy useful for visualization.

**Q:** How can I contribute to Awpy?
    We are always looking for people to help improve Awpy, no matter the skill-level. Please reach out on `Discord <https://discord.gg/W34XjsSs2H>`_ if you are interested.

**Q:** How should I attribute Awpy in my work?
    If you're posting on a casual site, like Twitter, you can simply link back to the Awpy Github repository. If you're working on an academic paper, you can cite `Analyzing the Differences between Professional and Amateur Esports through Win Probability <https://dl.acm.org/doi/abs/10.1145/3485447.3512277>`_.